# placeholdername app

This ⚡ [Lightning app](https://lightning.ai/) ⚡ was generated automatically with:

```bash
lightning init app placeholdername
```

## To run placeholdername

First, install placeholdername (warning: this app has not been officially approved on the lightning gallery):

```bash
lightning install app https://github.com/theUser/placeholdername
```

Once the app is installed, run it locally with:

```bash
lightning run app placeholdername/app.py
```

Run it on the [lightning cloud](https://lightning.ai/) with:

```bash
lightning run app placeholdername/app.py --cloud
```

## to test and link

Run flake to make sure all your styling is consistent (it keeps your team from going insane)

```bash
flake8 .
```

To test, follow the README.md instructions in the tests folder.
